@@ -7,13 +7,13 @@
  * Copyright (c) 2009-2012,
  * Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
  *
- * Copyright (c) 2009-2012, 2021,
+ * Copyright (c) 2009-2012, 2021, 2024,
  * Technische Universitaet Dresden, Germany
  *
  * Copyright (c) 2009-2012,
  * University of Oregon, Eugene, USA
  *
- * Copyright (c) 2009-2012,
+ * Copyright (c) 2009-2012, 2024,
  * Forschungszentrum Juelich GmbH, Germany
  *
  * Copyright (c) 2009-2012,
@@ -370,7 +370,19 @@ enum OTF2_RegionRole_enum
      *
      *  @since Version 2.1.
      */
-    OTF2_REGION_ROLE_FILE_IO_METADATA = 38
+    OTF2_REGION_ROLE_FILE_IO_METADATA = 38,
+
+    /** @brief E.g. OpenMP "cancel" construct
+     *
+     *  @since Version 3.1.
+     */
+    OTF2_REGION_ROLE_CANCEL           = 39,
+
+    /** @brief An accelerator kernel executing on an accelerator stream.
+     *
+     *  @since Version 3.1.
+     */
+    OTF2_REGION_ROLE_KERNEL           = 40
 };
 
 
