@@ -7,7 +7,7 @@
  * Copyright (c) 2009-2013,
  * Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
  *
- * Copyright (c) 2009-2014, 2021,
+ * Copyright (c) 2009-2014, 2021, 2023,
  * Technische Universitaet Dresden, Germany
  *
  * Copyright (c) 2009-2013,
@@ -64,13 +64,13 @@ extern "C" {
 /** @brief Major version number of this OTF2 version. */
 #define OTF2_VERSION_MAJOR  3
 /** @brief Minor version number of this OTF2 version. */
-#define OTF2_VERSION_MINOR  0
+#define OTF2_VERSION_MINOR  1
 /** @brief Bugfix version number of this OTF2 version. */
-#define OTF2_VERSION_BUGFIX 2
+#define OTF2_VERSION_BUGFIX 1
 /** @brief Any string suffix of this OTF2 version. */
 #define OTF2_VERSION_SUFFIX ""
 /** @brief The OTF2 version as string. */
-#define OTF2_VERSION        "3.0.2"
+#define OTF2_VERSION        "3.1.1"
 /** @} */
 
 
@@ -969,7 +969,16 @@ enum OTF2_Paradigm_enum
      *
      *  @since Version 2.3.
      */
-    OTF2_PARADIGM_KOKKOS             = 24
+    OTF2_PARADIGM_KOKKOS             = 24,
+
+    /** @brief OpenMP target functions and kernels.
+     *
+     *  @pclass{OTF2_PARADIGM_CLASS_ACCELERATOR}
+     *  @pproperty{OTF2_PARADIGM_PROPERTY_RMA_ONLY,@eref{OTF2_TRUE}}
+     *
+     *  @since Version 3.1.
+     */
+    OTF2_PARADIGM_OPENMP_TARGET      = 25
 };
 
 
@@ -1055,7 +1064,25 @@ enum OTF2_ThumbnailType_enum
 
     /** @brief The referenced definitions are of type @eref{Attribute}.
      */
-    OTF2_THUMBNAIL_TYPE_ATTRIBUTES = 2
+    OTF2_THUMBNAIL_TYPE_ATTRIBUTES = 2,
+
+    /** @brief The referenced definitions are of type @eref{Comm}.
+     *
+     *  @since Version 3.1.
+     */
+    OTF2_THUMBNAIL_TYPE_COMM       = 3,
+
+    /** @brief The referenced definitions are of type @eref{RmaWin}.
+     *
+     *  @since Version 3.1.
+     */
+    OTF2_THUMBNAIL_TYPE_RMA_WIN    = 4,
+
+    /** @brief The referenced definitions are of type @eref{IoHandle}.
+     *
+     *  @since Version 3.1.
+     */
+    OTF2_THUMBNAIL_TYPE_IO_HANDLE  = 5
 };
 
 
