@@ -7,10 +7,10 @@ import copy
 
 
 try:
-    from .__version__ import __version__, __version_info__
+    from .__version__ import __version__, __version_info__, __interface__
 except ModuleNotFoundError:
     # in an out-of-tree build, __version__.py will be generated in the build dir
-    from __version__ import __version__, __version_info__
+    from __version__ import __version__, __version_info__, __interface__
 
 __all__ = [
     'pluralize',
@@ -36,6 +36,7 @@ __all__ = [
     'Version',
     '__version__',
     '__version_info__',
+    '__interface__',
     'types',
     'enums',
     'defs',
