@@ -174,7 +174,7 @@ otf2_thumb_reader_new( OTF2_Archive* archive,
 
     OTF2_ErrorCode status = OTF2_SUCCESS;
 
-    /* Allocate new writer */
+    /* Allocate new reader */
     reader = ( OTF2_ThumbReader* )calloc( 1, sizeof( OTF2_ThumbReader ) );
     if ( !reader )
     {
@@ -199,14 +199,6 @@ otf2_thumb_reader_new( OTF2_Archive* archive,
     reader->archive  = archive;
     reader->thumb_id = thumbID;
 
-    /* read thumb header */
-    status = otf2_thumb_reader_read_header( reader );
-    if ( status != OTF2_SUCCESS )
-    {
-        otf2_thumb_reader_delete( reader );
-        return NULL;
-    }
-
     return reader;
 
 clean_mem_new:
@@ -257,7 +249,20 @@ otf2_thumb_reader_open_file( OTF2_ThumbReader* reader )
                             "Reader Object is not valid!" );
     }
 
-    return otf2_buffer_open_file( reader->buffer );
+    OTF2_ErrorCode status = otf2_buffer_open_file( reader->buffer );
+    if ( status != OTF2_SUCCESS )
+    {
+        return UTILS_ERROR( status, "Thumbnail open failed!" );
+    }
+
+    /* read thumb header */
+    status = otf2_thumb_reader_read_header( reader );
+    if ( status != OTF2_SUCCESS )
+    {
+        return UTILS_ERROR( status, "Could not read thumbnail header!" );
+    }
+
+    return status;
 }
 
 
@@ -421,7 +426,7 @@ otf2_thumb_reader_read_header( OTF2_ThumbReader* reader )
     ret = OTF2_Buffer_ReadString( reader->buffer, &tmp_string );
     if ( OTF2_SUCCESS != ret )
     {
-        return UTILS_ERROR( ret, "Could not read record of unknown type." );
+        return UTILS_ERROR( ret, "Could not read thumbnail name." );
     }
     reader->name = UTILS_CStr_dup( tmp_string );
     if ( !reader->name )
@@ -433,7 +438,7 @@ otf2_thumb_reader_read_header( OTF2_ThumbReader* reader )
     ret = OTF2_Buffer_ReadString( reader->buffer, &tmp_string );
     if ( OTF2_SUCCESS != ret )
     {
-        return UTILS_ERROR( ret, "Could not read record of unknown type." );
+        return UTILS_ERROR( ret, "Could not read thumbnail description." );
     }
     reader->description = UTILS_CStr_dup( tmp_string );
     if ( !reader->description )
