@@ -1,7 +1,7 @@
 /*
  * This file is part of the Score-P software (http://www.score-p.org)
  *
- * Copyright (c) 2013-2014, 2021,
+ * Copyright (c) 2013-2014, 2021, 2023,
  * Technische Universitaet Dresden, Germany
  *
  * Copyright (c) 2015,
@@ -649,9 +649,9 @@ otf2_sion_open_read( OTF2_Archive* archive,
      */
     if ( OTF2_COLLECTIVES_ROOT == global_rank )
     {
-        errno = 0;
+        /* fopen does not reliable set errno (Intel oneAPI 2023.2.1) */
         FILE* file_exists = fopen( file_type_data->symbolic_file_path, "r" );
-        status = UTILS_Error_FromPosix( errno );
+        status = file_exists ? OTF2_SUCCESS : OTF2_ERROR_ENOENT;
         if ( file_exists )
         {
             fclose( file_exists );
