@@ -1,9 +1,7 @@
 import re
 from itertools import chain
 from collections import namedtuple
-from six import with_metaclass, integer_types, string_types
 from numbers import Number
-from builtins import int
 
 import _otf2
 
@@ -27,7 +25,7 @@ class DefinitionField(namedtuple("DefinitionField", ['name', 'type', 'private_na
         # Special case: Strings are supposed to be created as native strings
         # instead of String definitions
         if expected_type is String:
-            expected_type = string_types
+            expected_type = str
 
         if isinstance(value, expected_type):
             return value
@@ -185,7 +183,7 @@ class _RefDefinitionMeta(_DefinitionMeta):
         return _DefinitionMeta.__new__(mcls, name, bases, namespace)
 
 
-class _Definition(with_metaclass(_DefinitionMeta, object)):
+class _Definition(metaclass=_DefinitionMeta):
     """
     Any definition. It is attached to a registry.
     """
@@ -282,7 +280,7 @@ class _Definition(with_metaclass(_DefinitionMeta, object)):
         return "{}: {}".format(type(self).__name__, self._str_fields())
 
 
-class _RefDefinition(with_metaclass(_RefDefinitionMeta, _Definition)):
+class _RefDefinition(_Definition, metaclass=_RefDefinitionMeta):
     """
     A Definition with a ref (id) and a corresponding IdRegistry that manages this definition.
     """
@@ -328,7 +326,7 @@ class _RefDefinition(with_metaclass(_RefDefinitionMeta, _Definition)):
 
 
 class String(_RefDefinition):
-    _fields = ('name', no_default, string_types),
+    _fields = ('name', no_default, str),
 
 
 class _NamedRefDefinition(_RefDefinition):
@@ -370,7 +368,7 @@ class _PropertyDefinition(_Definition):
             if isinstance(arg1, Parameter):
                 # Basically any _NamedRefDefinition would be ok, but there's no use case currently
                 key = arg1.name
-            elif isinstance(arg1, string_types):
+            elif isinstance(arg1, str):
                 key = arg1
             else:
                 raise TypeError("Invalid type for name (can be string or Parameter)")
@@ -402,10 +400,10 @@ class _PropertyDefinition(_Definition):
 
 class ClockProperties(_Definition):
     # We don't want numbers.Number here.
-    _fields = (('timer_resolution', no_default, integer_types),
-               ('global_offset', 0, integer_types),
-               ('trace_length', 0, integer_types),
-               ('realtime_timestamp', Undefined.TIMESTAMP.value, integer_types))
+    _fields = (('timer_resolution', no_default, int),
+               ('global_offset', 0, int),
+               ('trace_length', 0, int),
+               ('realtime_timestamp', Undefined.TIMESTAMP.value, int))
 
 
 class Attribute(_NamedRefDefinition):
