@@ -7,7 +7,7 @@
  * Copyright (c) 2009-2013,
  * Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
  *
- * Copyright (c) 2009-2014, 2016,
+ * Copyright (c) 2009-2014, 2016, 2023,
  * Technische Universitaet Dresden, Germany
  *
  * Copyright (c) 2009-2013,
@@ -38,7 +38,7 @@ static int otf2_EVENT_COLUMN_WIDTH = 32;
 
 /** @internal
  *  @brief max value of an OTF2_Paradigm entry + 1. */
-static int otf2_max_known_paradigm = 24 + 1;
+static int otf2_max_known_paradigm = 25 + 1;
 
 static inline const char*
 otf2_print_get_raw_boolean( OTF2_Boolean boolean )
@@ -330,6 +330,8 @@ otf2_print_get_raw_paradigm( OTF2_Paradigm paradigm )
             return "HIP";
         case OTF2_PARADIGM_KOKKOS:
             return "KOKKOS";
+        case OTF2_PARADIGM_OPENMP_TARGET:
+            return "OPENMP_TARGET";
 
         default:
             return NULL;
@@ -425,6 +427,12 @@ otf2_print_get_raw_thumbnail_type( OTF2_ThumbnailType thumbnailType )
             return "METRIC";
         case OTF2_THUMBNAIL_TYPE_ATTRIBUTES:
             return "ATTRIBUTES";
+        case OTF2_THUMBNAIL_TYPE_COMM:
+            return "COMM";
+        case OTF2_THUMBNAIL_TYPE_RMA_WIN:
+            return "RMA_WIN";
+        case OTF2_THUMBNAIL_TYPE_IO_HANDLE:
+            return "IO_HANDLE";
 
         default:
             return NULL;
@@ -635,6 +643,10 @@ otf2_print_get_raw_region_role( OTF2_RegionRole regionRole )
             return "REALLOCATE";
         case OTF2_REGION_ROLE_FILE_IO_METADATA:
             return "FILE_IO_METADATA";
+        case OTF2_REGION_ROLE_CANCEL:
+            return "CANCEL";
+        case OTF2_REGION_ROLE_KERNEL:
+            return "KERNEL";
 
         default:
             return NULL;
