@@ -7,7 +7,7 @@
  * Copyright (c) 2009-2012,
  * Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
  *
- * Copyright (c) 2009-2014,
+ * Copyright (c) 2009-2014, 2024,
  * Technische Universitaet Dresden, Germany
  *
  * Copyright (c) 2009-2012,
@@ -105,7 +105,9 @@ static uint64_t otf2_Region;
 
 
 static OTF2_ErrorCode
-create_archive( bool use_sion );
+create_archive( const char*        archivePath,
+                const char*        traceName,
+                OTF2_FileSubstrate substrate );
 
 static OTF2_ErrorCode
 check_archive( const char* trace );
@@ -182,10 +184,20 @@ main( int   argc,
 
     if ( argc == 1 )
     {
-        status = create_archive( !!getenv( "OTF2_TEST_USE_SION" ) );
+        bool use_sion = !!getenv( "OTF2_TEST_USE_SION" );
+
+        status = create_archive( use_sion
+                                 ? OTF2_ARCHIVE_PATH "_sion"
+                                 : OTF2_ARCHIVE_PATH,
+                                 OTF2_TRACE_NAME,
+                                 use_sion
+                                 ? OTF2_SUBSTRATE_SION
+                                 : OTF2_SUBSTRATE_POSIX );
         check_status( status, "Create Archive." );
 
-        status = check_archive( OTF2_ARCHIVE_PATH "/" OTF2_TRACE_NAME ".otf2" );
+        status = check_archive( use_sion
+                                ? OTF2_ARCHIVE_PATH "_sion/" OTF2_TRACE_NAME ".otf2"
+                                : OTF2_ARCHIVE_PATH "/" OTF2_TRACE_NAME ".otf2" );
         check_status( status, "Check Archive." );
     }
     else
@@ -206,17 +218,17 @@ main( int   argc,
  *                          if an error occurs.
  */
 OTF2_ErrorCode
-create_archive( bool use_sion )
+create_archive( const char*        archivePath,
+                const char*        traceName,
+                OTF2_FileSubstrate substrate )
 {
     /* Create new archive handle. */
-    OTF2_Archive* archive = OTF2_Archive_Open( OTF2_ARCHIVE_PATH,
-                                               OTF2_TRACE_NAME,
+    OTF2_Archive* archive = OTF2_Archive_Open( archivePath,
+                                               traceName,
                                                OTF2_FILEMODE_WRITE,
                                                256 * 1024,
                                                OTF2_UNDEFINED_UINT64,
-                                               use_sion
-                                               ? OTF2_SUBSTRATE_SION
-                                               : OTF2_SUBSTRATE_POSIX,
+                                               substrate,
                                                OTF2_COMPRESSION_NONE );
     check_pointer( archive, "Create archive" );
 
