@@ -9,7 +9,7 @@
 ## Copyright (c) 2009-2011,
 ## Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
 ##
-## Copyright (c) 2009-2014,
+## Copyright (c) 2009-2014, 2024,
 ## Technische Universitaet Dresden, Germany
 ##
 ## Copyright (c) 2009-2011,
@@ -35,9 +35,9 @@ set -e
 
 cleanup()
 {
-    rm -rf OTF2_Integrity_trace
+    rm -rf OTF2_Integrity_trace_sion
 }
-trap cleanup EXIT
-
+${KEEP_TEST_OUTPUT:+: }trap cleanup EXIT
 cleanup
+
 OTF2_TEST_USE_SION=1 $VALGRIND ./OTF2_Integrity_test
