@@ -3,7 +3,7 @@
 ##
 ## This file is part of the Score-P software (http://www.score-p.org)
 ##
-## Copyright (c) 2009-2013,
+## Copyright (c) 2009-2013, 2024,
 ## Technische Universitaet Dresden, Germany
 ##
 ## This software may be modified and distributed under the terms of
@@ -19,7 +19,8 @@ cleanup()
 {
     rm -rf OTF2_OLD_CHUNK_LIST_TEST_PATH
 }
-trap cleanup EXIT
-
+${KEEP_TEST_OUTPUT:+: }trap cleanup EXIT
 cleanup
+
+unset OTF2_TEST_USE_SION
 $VALGRIND ./OTF2_Old_Chunk_List_test
