@@ -1,7 +1,7 @@
 /*
  * This file is part of the Score-P software (http://www.score-p.org)
  *
- * Copyright (c) 2013-2014,
+ * Copyright (c) 2013-2014, 2024,
  * Technische Universitaet Dresden, Germany
  *
  * This software may be modified and distributed under the terms of
@@ -42,14 +42,25 @@
 #define OTF2_TEST_FLUSH_DEFAULT OTF2_FLUSH
 #include <otf2-test/flush.h>
 
+/* ___ Global defines _______________________________________________________ */
+
+
+/** @brief Archive path */
+#define OTF2_ARCHIVE_PATH "OTF2_Snapshot_Seek_trace"
+
+/** @brief Trace name */
+#define OTF2_TRACE_NAME "TestTrace"
+
 /* ___ Prototypes for static functions. _____________________________________ */
 
 
 static OTF2_ErrorCode
-create_archive( bool use_sion );
+create_archive( const char*        archivePath,
+                const char*        traceName,
+                OTF2_FileSubstrate substrate );
 
 static OTF2_ErrorCode
-check_archive( void );
+check_archive( const char* trace );
 
 
 
@@ -105,11 +116,20 @@ main( int    argc,
 {
     OTF2_ErrorCode status;
 
-    status = create_archive( argc > 1 );
+    bool use_sion = !!getenv( "OTF2_TEST_USE_SION" );
+
+    status = create_archive( use_sion
+                             ? OTF2_ARCHIVE_PATH "_sion"
+                             : OTF2_ARCHIVE_PATH,
+                             OTF2_TRACE_NAME,
+                             use_sion
+                             ? OTF2_SUBSTRATE_SION
+                             : OTF2_SUBSTRATE_POSIX );
     check_status( status, "Create Archive." );
 
-    status = check_archive();
-    check_status( status, "Check Archive." );
+    status = check_archive( use_sion
+                            ? OTF2_ARCHIVE_PATH "_sion/" OTF2_TRACE_NAME ".otf2"
+                            : OTF2_ARCHIVE_PATH "/" OTF2_TRACE_NAME ".otf2" );
 
     return EXIT_SUCCESS;
 }
@@ -123,19 +143,19 @@ main( int    argc,
  *                          if an error occurs.
  */
 OTF2_ErrorCode
-create_archive( bool use_sion )
+create_archive( const char*        archivePath,
+                const char*        traceName,
+                OTF2_FileSubstrate substrate )
 {
     OTF2_ErrorCode status;
 
     /* Create new archive handle. */
-    OTF2_Archive* archive = OTF2_Archive_Open( "OTF2_Snapshot_Seek_trace",
-                                               "TestTrace",
+    OTF2_Archive* archive = OTF2_Archive_Open( archivePath,
+                                               traceName,
                                                OTF2_FILEMODE_WRITE,
                                                256 * 1024,
                                                4 * 1024 * 1024,
-                                               use_sion
-                                               ? OTF2_SUBSTRATE_SION
-                                               : OTF2_SUBSTRATE_POSIX,
+                                               substrate,
                                                OTF2_COMPRESSION_NONE );
     check_pointer( archive, "Create archive" );
 
@@ -273,12 +293,12 @@ create_archive( bool use_sion )
  *                          if an error occurs.
  */
 OTF2_ErrorCode
-check_archive( void )
+check_archive( const char* trace )
 {
     OTF2_ErrorCode status;
 
     /* Get a reader handle. */
-    OTF2_Reader* reader = OTF2_Reader_Open( "OTF2_Snapshot_Seek_trace/TestTrace.otf2" );
+    OTF2_Reader* reader = OTF2_Reader_Open( trace );
     check_pointer( reader, "Create new reader handle." );
     status = OTF2_Reader_SetSerialCollectiveCallbacks( reader );
     check_status( status, "Set serial mode." );
