@@ -3,7 +3,7 @@
 ##
 ## This file is part of the Score-P software (http://www.score-p.org)
 ##
-## Copyright (c) 2013-2014,
+## Copyright (c) 2013-2014, 2024,
 ## Technische Universitaet Dresden, Germany
 ##
 ## This software may be modified and distributed under the terms of
@@ -17,9 +17,9 @@ set -e
 
 cleanup()
 {
-    rm -rf OTF2_Snapshot_Seek_trace
+    rm -rf OTF2_Snapshot_Seek_trace_sion
 }
-trap cleanup EXIT
-
+${KEEP_TEST_OUTPUT:+: }trap cleanup EXIT
 cleanup
-$VALGRIND ./OTF2_Snapshot_Seek_test use_sion
+
+OTF2_TEST_USE_SION=1 $VALGRIND ./OTF2_Snapshot_Seek_test
