@@ -9,7 +9,7 @@
 ## Copyright (c) 2009-2011,
 ## Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
 ##
-## Copyright (c) 2009-2011, 2013-2014,
+## Copyright (c) 2009-2011, 2013-2014, 2024,
 ## Technische Universitaet Dresden, Germany
 ##
 ## Copyright (c) 2009-2011,
@@ -37,7 +37,8 @@ cleanup()
 {
     rm -rf OTF2_Timer_sync_trace
 }
-trap cleanup EXIT
-
+${KEEP_TEST_OUTPUT:+: }trap cleanup EXIT
 cleanup
+
+unset OTF2_TEST_USE_SION
 $VALGRIND ./OTF2_Timer_sync_test
