@@ -7,7 +7,7 @@
  * Copyright (c) 2009-2012,
  * Gesellschaft fuer numerische Simulation mbH Braunschweig, Germany
  *
- * Copyright (c) 2009-2014,
+ * Copyright (c) 2009-2014, 2024,
  * Technische Universitaet Dresden, Germany
  *
  * Copyright (c) 2009-2012,
@@ -108,10 +108,12 @@ static uint64_t unknown_records_read = 0;
 
 
 static OTF2_ErrorCode
-create_archive( bool use_sion );
+create_archive( const char*        archivePath,
+                const char*        traceName,
+                OTF2_FileSubstrate substrate );
 
 static OTF2_ErrorCode
-check_archive( void );
+check_archive( const char* trace );
 
 static void
 write_definitions( OTF2_Archive* archive );
@@ -153,11 +155,21 @@ main( int    argc,
 {
     OTF2_ErrorCode status;
 
-    status = create_archive( argc > 1 );
-    check_status( status, "Create archive." );
+    bool use_sion = !!getenv( "OTF2_TEST_USE_SION" );
 
-    check_archive();
-    check_status( status, "Check archive." );
+    status = create_archive( use_sion
+                             ? OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR "_sion"
+                             : OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR,
+                             OTF2_UNKNOWN_RECORD_TEST_TRACE_NAME,
+                             use_sion
+                             ? OTF2_SUBSTRATE_SION
+                             : OTF2_SUBSTRATE_POSIX );
+    check_status( status, "Create Archive." );
+
+    status = check_archive( use_sion
+                            ? OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR "_sion/" OTF2_UNKNOWN_RECORD_TEST_TRACE_NAME ".otf2"
+                            : OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR "/" OTF2_UNKNOWN_RECORD_TEST_TRACE_NAME ".otf2" );
+    check_status( status, "Check Archive." );
 
     return 0;
 }
@@ -170,18 +182,18 @@ main( int    argc,
  *                          if an error occurs.
  */
 OTF2_ErrorCode
-create_archive( bool use_sion )
+create_archive( const char*        archivePath,
+                const char*        traceName,
+                OTF2_FileSubstrate substrate )
 {
     OTF2_ErrorCode status;
 
-    OTF2_Archive* archive = OTF2_Archive_Open( OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR,
-                                               OTF2_UNKNOWN_RECORD_TEST_TRACE_NAME,
+    OTF2_Archive* archive = OTF2_Archive_Open( archivePath,
+                                               traceName,
                                                OTF2_FILEMODE_WRITE,
                                                OTF2_UNKNOWN_RECORD_TEST_CHUNK_SIZE,
                                                4 * 1024 * 1024,
-                                               use_sion
-                                               ? OTF2_SUBSTRATE_SION
-                                               : OTF2_SUBSTRATE_POSIX,
+                                               substrate,
                                                OTF2_COMPRESSION_NONE );
     check_pointer( archive, "Create writer archive handle" );
 
@@ -396,25 +408,12 @@ write_events( OTF2_Archive* archive )
 }
 
 OTF2_ErrorCode
-check_archive( void )
+check_archive( const char* trace )
 {
     OTF2_ErrorCode status;
 
-    /* Get string length of trace file path:
-     * length of path to directory
-     * + one additional character for directory separator
-     * + length of trace file name
-     * + five additional for '.otf2' file extension */
-    size_t string_length = strlen( OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR ) + strlen( OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR ) + 6;
-    char*  trace_name    = malloc( ( string_length + 1 ) * sizeof( char ) );
-    if ( trace_name == NULL )
-    {
-        return OTF2_ERROR_ENOMEM;
-    }
-    snprintf( trace_name, string_length, "%s/%s.otf2", OTF2_UNKNOWN_RECORD_TEST_TRACE_DIR, OTF2_UNKNOWN_RECORD_TEST_TRACE_NAME );
-
     /* Open reader. */
-    OTF2_Reader* reader = OTF2_Reader_Open( trace_name );
+    OTF2_Reader* reader = OTF2_Reader_Open( trace );
     check_pointer( reader, "Create new reader handle." );
 
     status = OTF2_Reader_SetSerialCollectiveCallbacks( reader );
