@@ -14,7 +14,7 @@ class TestOTF2Combined(unittest.TestCase):
         self.tmp_dirname = mkdtemp(prefix=os.path.basename(os.path.abspath(__file__))[:-3] + '_tmp', dir=os.getcwd())
 
     def tearDown(self):
-        if 'V' in os.environ and os.environ['V'] != '':
+        if os.getenv('KEEP_TEST_OUTPUT', '') != '':
             print(self.tmp_dirname)
         else:
             rmtree(self.tmp_dirname)
