@@ -27,7 +27,7 @@ class TestOTF2UserData(unittest.TestCase):
 
     def tearDown(self):
         os.chdir(self.old_cwd)
-        if 'V' in os.environ and os.environ['V'] != '':
+        if os.getenv('KEEP_TEST_OUTPUT', '') != '':
             print(self.tmp_dirname)
         else:
             rmtree(self.tmp_dirname)
